summaryrefslogtreecommitdiffstats
path: root/kdirstat/ktreemapview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdirstat/ktreemapview.h')
-rw-r--r--kdirstat/ktreemapview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdirstat/ktreemapview.h b/kdirstat/ktreemapview.h
index 61e4de6..63d8b8b 100644
--- a/kdirstat/ktreemapview.h
+++ b/kdirstat/ktreemapview.h
@@ -32,7 +32,7 @@
class TQMouseEvent;
-class KConfig;
+class TDEConfig;
namespace KDirStat
{
@@ -168,7 +168,7 @@ namespace KDirStat
void deleteNotify( KFileInfo * node );
/**
* Read some parameters from the global @ref KConfig object.
**/
void readConfig();
@@ -373,7 +373,7 @@ namespace KDirStat
/**
* Convenience method to read a color from 'config'.
**/
- TQColor readColorEntry( KConfig * config,
+ TQColor readColorEntry( TDEConfig * config,
const char * entryName,
TQColor defaultColor );
@@ -168,7 +168,7 @@ namespace KDirStat
void deleteNotify( KFileInfo * node );
/**
- * Read some parameters from the global @ref KConfig object.
+ * Read some parameters from the global @ref TDEConfig object.
**/
void readConfig();